# Models taken from Pyomo.GDP examples directory

These models are among the oldest in the library.
They were primarily developed by Emma Savannah Johnson (esjohn@sandia.gov), and are simply reproduced here in importable form.
